@@ -3,7 +3,7 @@ use Mojo::Base 'Mojolicious::Plugin';
 
 # ABSTRACT: create form fields based on a definition in a JSON file
 
-our $VERSION = '0.31';
+our $VERSION = '0.32';
 
 use Carp;
 use File::Basename;
@@ -17,6 +17,9 @@ use Mojo::ByteStream;
 use Mojo::JSON qw(decode_json);
 
 use Mojolicious ();
+
+has dir => sub {["."]} ;
+
 my $selected_value = Mojolicious->VERSION < 6.16 ? 'selected' : undef;
 my $checked_value  = Mojolicious->VERSION < 6.16 ? 'checked'  : undef;
 
@@ -26,7 +29,12 @@ sub register {
     $config //= {};
   
     my %configs;
-    my $dir = $config->{dir} || '.';
+    if(ref $config->{dir} eq "ARRAY"){
+        @{$self->dir} = @{$config->{dir}}; 
+    }
+    else{
+        @{$self->dir} = ($config->{dir});
+    }
   
     my %valid_types = (
         %{ $config->{types} || {} },
@@ -46,20 +54,28 @@ sub register {
                 return sort keys %configfiles;
             }
 
-            my $dir = IO::Dir->new( $dir );
+            for my $dir (@{$self->dir}){
+                my $dir = IO::Dir->new( $dir );
 
-            FILE:
-            while ( my $file = $dir->read ) {
-                next FILE if $file !~ m{\.json\z};
-                my $filename = basename $file;
-                $filename    =~ s{\.json\z}{};
-                $configfiles{$filename} = 1;
+                FILE:
+                while ( my $file = $dir->read ) {
+                    next FILE if $file !~ m{\.json\z};
+
+                    my $filename = basename $file;
+                    $filename    =~ s{\.json\z}{};
+
+                    $configfiles{$filename} = 1;
+                }
             }
 
             return sort keys %configfiles;
         }
     );
 
+    $app->helper(
+        "form_fields_from_json_dir" => sub {return $self->dir}
+    );
+
     $app->helper(
         fields => sub {
             my ($c, $file, $params) = @_;
@@ -192,11 +208,23 @@ sub register {
             return '' if !$file;
   
             if ( !$configs{$file} && !ref $file ) {
-                my $path = File::Spec->catfile( $dir, $file . '.json' );
-                return '' if !-r $path;
-  
+                my $path;
+
+                # search until first match
+                my $i=0;
+                do {
+                    my $_path= File::Spec->catfile( $self->dir->[$i], $file . '.json' );
+                    $path = $_path if -r $_path;
+                } while ( not defined $path and ++$i <= $#{$self->dir} );
+							
+                if( not defined $path){
+                    $app->log->error( "FORMFIELDS $file: not found in directories" );
+                    $app->log->error( "  $_") for @{$self->dir};
+                    return '';
+                }
+ 
                 eval {
-                    my $content = Mojo::Asset::File->new( path => $path )->slurp;
+                    my $content     = Mojo::Asset::File->new( path => $path )->slurp;
                     $configs{$file} = decode_json $content;
                 } or do {
                     $app->log->error( "FORMFIELDS $file: $@" );
@@ -690,7 +718,7 @@ Mojolicious::Plugin::FormFieldsFromJSON - create form fields based on a definiti
 
 =head1 VERSION
 
-version 0.31
+version 0.32
 
 =head1 SYNOPSIS
 
@@ -718,6 +746,17 @@ The directory where the json files for form field configuration are located
     dir => '/home/mojo/fields',
   });
 
+You can also pass an arrayreference with directory names. This will help when you
+store the JSON files where your templates are...
+
+  $self->plugin( 'FormFieldsFromJSON' => {
+    dir => [
+      '/home/mojo/templates/admin/json',
+      '/home/mojo/templates/author/json',
+      '/home/mojo/templates/guest/json',
+    ]
+  });
+
 =item * template
 
 With template you can define a template for the form fields.
@@ -2126,7 +2165,7 @@ Renee Baecker <reneeb@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Renee Baecker.
+This software is Copyright (c) 2016 by Renee Baecker.
 
 This is free software, licensed under:
 
